close all; clear all; clc;
%% Initializations
X = [0,2*pi];               % Space interval
T = [0,1];                  % Time interval
nu = @(x) .02 + 0*x;          % Diffusion function
Dnu = @(x) 0 + 0*x;         % Derivative of Diffusion function
f = @(x) 3./(5-4*cos(x));   % Initial condition

vec = 4:9;                  % Levels for space discretiziation
m = 3;                      % Shift for plotting
psol = 1;                   % Plot actual solution (0 off /1 on)
loc = char('1_3_1_');       % problem name for figures
test = 2;                   % for saving the figures 1: nu = 2, 2:nu = .02
sdata = 0;                  % switch for saving figures

%% Preallocation
L = length(vec);
err = cell(L,1);
uc = cell(L,1);                 
xc = cell(L,1);
tc = cell(L,1);

%% Call method and store data
for J = vec
    n = 2^(J-1);
    M = 4*n;
    N = [n, M];
    [uc{J-m},xc{J-m},tc{J-m}] = spec_full(X,T,N,f,nu,Dnu);
    sol = solution(xc{J-m},tc{J-m},nu);
    u = uc{J-m};
    for K = 1:length(tc{J-m})
        err{J-m}(K) = norm(sol(:,K) - u(:,K));
    end

end

%% Plot solution and approximation
x = xc{vec(end)-m};
t = tc{vec(end)-m};
gVec = 1:10:M;
tG = tc{6}(gVec);

f1 = figure(1);
surf(tG,x(1:10:end),u((1:10:end),gVec));
title('approximation');
if sdata
    f1n = sprintf('%s%da.png',loc,test);
    print(f1, f1n, '-dpng');
end
if psol
    figure(2)
    surf(t,x(1:10:end),sol((1:10:end),:));
    title('solution');
end

%% Plot of error vs level
errL = zeros(length(vec),1);
for J = vec
    errL(J-m) = sum(err{J-m});
end
f3 = figure(3);
semilogy(vec,errL)
title('semilog of L2 error');
xlabel('Exponent of level');
if sdata
    f3n = sprintf('%s%dc.png',loc,test);
    print(f3, f3n, '-dpng');
end

%% Time slice plot
dataM  = char('o', 'd','.','s','+','v');
dataC  = char('b', 'm','g','k','r','c');
f4 = figure(4);
pgVec = floor([1 M/4 M/2 3*M/4 M]);
for J = 1:5
    plot(x,u(:,pgVec(J)),'color',dataC(J));
    hold on
end
title('Time slices of approximation');
legend('t=0','t=.25','t=.5','t=.75', 't=1')
hold off
if sdata
    f4n = sprintf('%s%db.png',loc,test);
    print(f4, f4n, '-dpng');
end

%% Error plot for various levels, error vs time plot
f5 = figure(5);
for K = 1:6
    semilogy(tc{K}([1 2 3 4:2^(vec(K)-2):end]),err{K}([1 2 3 4:2^(vec(K)-2):end]),'marker',dataM(K),'color',dataC(K));
    hold on
end
title('Error at various mesh sizes');
legend('dx=0.3927','dx=0.1963','dx=0.0982','dx=0.0491','dx=0.0245','dx=0.0123')
xlabel('time')
if sdata
    f5n = sprintf('%s%dd.png',loc,test);
    print(f5, f5n, '-dpng');
end